@@ -1,7 +1,7 @@
 #!/usr/bin/perl -w
 
 # catkin.pl
-# Copyright (C) 2002-2003 colin z robertson
+# Copyright (C) 2002-2004 colin z robertson
 # 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,11 +19,10 @@
 
 # path to data dir:
 my $CATKIN_DIR = '/path/to/catkin/config/dir/';
+# path to libraries (if necessary):
+my @LIB_DIRS = qw( /path/to/perl/modules );
 
-BEGIN {
-	# path to libraries (if necessary):
-	my @LIB_DIRS = qw( /path/to/perl/modules );
-
+eval {
 	eval('
 		use lib @LIB_DIRS;
 		use strict;
@@ -32,17 +31,19 @@ BEGIN {
 		use Catkin::Interface;
 	');
 	if ($@) {
-		print "Content-Type: text/plain\n\nError: $@";
-		die $@;
+		die "Error in loading modules: $@\n";
 	}
+	# This is for IIS. You may want to remove it if you use a sane system.
+	my $logfile = "$CATKIN_DIR/errlog";
+	if (-e $logfile) { unlink $logfile if -s $logfile > 250000; }
+	open(STDERR,">>$logfile");
+	
+	my $cgi = new CGI();
+	my $catkin = new Catkin::Interface($CATKIN_DIR);
+	
+	print $catkin->process_cgi($cgi);
+};
+if ($@) {
+	print "Content-Type: text/plain\n\nError: $@";
+	exit;
 }
-
-# This is for IIS. You may want to remove it if you use a sane system.
-my $logfile = "$CATKIN_DIR/errlog";
-if (-e $logfile) { unlink $logfile if -s $logfile > 250000; }
-open(STDERR,">>$logfile");
-
-my $cgi = new CGI();
-my $catkin = new Catkin::Interface($CATKIN_DIR);
-
-print $catkin->process_cgi($cgi);
